@@ -72,8 +72,10 @@ class Qiniu(BackendBase):
                 if os.path.isfile(download_path):
                     os.remove(download_path)
                 self.create_dir_if_not_exists(download_path)
-                wget.download(url, download_path)
-                return True, download_path
+                path = self.download_file(url, download_path)
+                if path:
+                    return True, download_path
+                return self.get(download_path, bucket, bucket_name, tries+1)
         except Exception as e:
             traceback.print_exc()
             if tries >= 3:
@@ -92,7 +94,7 @@ class Qiniu(BackendBase):
                 if os.path.isfile(download_path):
                     os.remove(download_path)
                 self.create_dir_if_not_exists(download_path)
-                path = await self.download_file(url, download_path)
+                path = self.download_file(url, download_path)
                 if path:
                     return True, download_path
                 return await self.get_async(download_path, bucket, bucket_name, tries+1)
